<?php
/**
 * Outputs a checked="checked" if the value is checked
 */
function nlws_ehfi_checked( $value, $optionname ) {
	if ($optionname == $value)
		echo ' checked="checked"';	
}

/**
 * Add options page
 */
function nlws_ehfi_plugin_menu() {
	// Create a new options page
	$plugin_page = add_options_page( 'Enhanced Header / Footer Injections', 'Enhanced Header / Footer Injections', 'manage_options', 'nlws-ehfi-options', 'nlws_ehfi_options');
}


/**
 * Register settings
 */
function nlws_ehfi_register_settings() {
	// Register the settings
	register_setting( 'nlws_ehfi_settings', 'nlws_ehfi_settings' );
}


/**
 * Plugin activation hook
 */
function nlws_ehfi_activate() {
	// Only send if the plugin hasn't been activated before
	$isinstalled = get_option('nlws_ehfi_version');
	
	if (!$isinstalled) {
		
	}
	
	// Update version
	update_option( 'nlws_ehfi_version', NLWS_EHFI_VERSION );
	
	// Check to see if there are any default settings
	$hasglobaloptions = get_option('nlws_ehfi_settings');
	
	if (!$hasglobaloptions) {
		$defaultoptions = '';
		update_option('nlws_ehfi_settings', $defaultoptions);
	}
}


/**
 * Global Options Page
 */
function nlws_ehfi_options(){ ?>
	<div class="wrap">
		<div id="icon-users" class="icon32"></div><h2>Enhanced Header / Footer Injections</h2>
		<p>This plugin allows users to insert code into the header and footer sections of a theme on a page per page basis.&nbsp; Pages by default have no code injected into them but, can be assigned to use either global injections or per page injections.</p>
		
		<form method="post" action="options.php">
			<?php
			settings_fields( 'nlws_ehfi_settings' );
			$options = get_option( 'nlws_ehfi_settings' );
			?>
			<h3>Global Injection Settings</h3>
			<table class="form-table">
				<tr valign="top"><th scope="row"><?php _e( 'Global Header Code' ); ?></th>
					<td>
						<textarea id="nlws_ehfi_settings[global_header]" class="large-text" cols="50" rows="3" name="nlws_ehfi_settings[global_header]"><?php echo stripslashes( $options['global_header'] ); ?></textarea>
						<label class="description" for="nlws_ehfi_settings[global_header]"><?php _e( 'Enter a string that can be used to be inserted into your header.' ); ?></label>
					</td>
				</tr>
				
				<tr valign="top"><th scope="row"><?php _e( 'Global Footer Code' ); ?></th>
					<td>
						<textarea id="nlws_ehfi_settings[global_footer]" class="large-text" cols="50" rows="3" name="nlws_ehfi_settings[global_footer]"><?php echo stripslashes( $options['global_footer'] ); ?></textarea>
						<label class="description" for="nlws_ehfi_settings[global_footer]"><?php _e( 'Enter a string that can be used to be inserted into your footer.' ); ?></label>
					</td>
				</tr>
				
				<tr valign="top"><th scope="row"><?php _e( 'Enable for these Post Types' ); ?></th>
					<td>
						<?php
						$post_types=get_post_types();
						foreach ($post_types as $post_type ) :
						?>
							<input type="checkbox" id="nlws_ehfi_settings[enable_post_type_<?php echo $post_type; ?>]" name="nlws_ehfi_settings[enable_post_type_<?php echo $post_type; ?>]" value="1" <?php nlws_ehfi_checked($options['enable_post_type_' . $post_type], 1); ?> />
							<label class="description" for="nlws_ehfi_settings[enable_post_type_<?php echo $post_type; ?>]"><?php _e( $post_type ); ?></label><br />
						<?php endforeach; ?>
					</td>
				</tr>
				
				
			</table>
			<p class="submit">
		    	<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
		    </p>
		</form>
	</div><!-- .wrap -->
<?php }


/**
 * Add our meta box
 */
function nlws_ehfi_add_meta() {
	$options = get_option( 'nlws_ehfi_settings' );
	$post_types = get_post_types();
	foreach ($post_types as $post_type ) :
		if ($options['enable_post_type_' . $post_type]) {
			add_meta_box('nlws_ehfi_meta_section',
				__( 'Enhanced Header / Footer Injections', 'nlws_ehfi_domain' ), 
				'nlws_ehfi_output_meta',
				$post_type
			);
		}
	endforeach;
}

/**
 * Save the meta information
 */
function nlws_ehfi_save_post( $post_id ) {
	/**
	 * Verify if this is an auto save routine. 
	 * If it is our form has not been submitted, so we dont want to do anything
	 */
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
		return;


	/**
	 * Verify this came from the our screen and with proper authorization,
	 * because save_post can be triggered at other times
	 */
	if ( !wp_verify_nonce( $_POST['nlws_ehfi_noncename'], plugin_basename( __FILE__ ) ) )
		return;


	/**
	 * Check permissions
	 */
	if ( 'page' == $_POST['post_type'] ) {
		if ( !current_user_can( 'edit_page', $post_id ) )
			return;
	}
	else {
		if ( !current_user_can( 'edit_post', $post_id ) )
			return;
	}

	
	/**
	 * OK, we're authenticated: we need to find and save the data
	 */
	$mydata = $_POST['nlws_ehfi_meta'];
	//$mydata = $_POST;
	update_post_meta($post_id, '_nlws_efhi', $mydata);
}

/**
 * Save the meta information
 */
function nlws_ehfi_output_meta( $post ) {
	/**
	 * Use nonce for verification
	 */
	wp_nonce_field( plugin_basename( __FILE__ ), 'nlws_ehfi_noncename' );
	
	/**
	 * Get the data and build the meta box
	 */
	$meta = get_post_meta($post->ID,'_nlws_efhi',TRUE);
	$options = get_option( 'nlws_ehfi_settings' );?>
	<h4>Header Mode</h4>
	<p>
		<input type="radio" name="nlws_ehfi_meta[header_mode]" id="nlws_ehfi_header_mode_off" value="off" <?php if ($meta['header_mode']) nlws_ehfi_checked('off', $meta['header_mode']); else echo ' checked="checked"'; ?> class="nlws_ehfi_headermode" /> <label for="nlws_ehfi_header_mode_off" style="padding-right: 15px;">Off</label>
		<input type="radio" name="nlws_ehfi_meta[header_mode]" id="nlws_ehfi_header_mode_global" value="global" <?php nlws_ehfi_checked('global', $meta['header_mode']); ?> class="nlws_ehfi_headermode" /> <label for="nlws_ehfi_header_mode_global" style="padding-right: 15px;">Use Global Header</label>
		<input type="radio" name="nlws_ehfi_meta[header_mode]" id="nlws_ehfi_header_mode_perpage" value="perpage" <?php nlws_ehfi_checked('perpage', $meta['header_mode']); ?> class="nlws_ehfi_headermode" /> <label for="nlws_ehfi_header_mode_perpage">Use Per Page Header</label>
	</p>
	<pre class="nlws_ehfi_globalheader" <?php if(!($meta['header_mode']) || ($meta['header_mode'] == 'off') || ($meta['header_mode'] == 'perpage')) echo ' style="display: none"';?>><?php echo htmlspecialchars($options['global_header']); ?></pre>
	<p class="nlws_ehfi_customheader"  <?php if(!($meta['header_mode']) || ($meta['header_mode'] == 'off') || ($meta['header_mode'] == 'global')) echo ' style="display: none"';?>>
		<textarea name="nlws_ehfi_meta[header_text]" id="nlws_ehfi_meta[header_text]" rows="8" style="width: 100%"><?php echo $meta['header_text']; ?></textarea>
	</p>
	
	<h4>Footer Mode</h4>
	<p>
		<input type="radio" name="nlws_ehfi_meta[footer_mode]" id="nlws_ehfi_footer_mode_off" value="off" <?php if ($meta['footer_mode']) nlws_ehfi_checked('off', $meta['footer_mode']); else echo ' checked="checked"'; ?> class="nlws_ehfi_footermode" /> <label for="nlws_ehfi_footer_mode_off" style="padding-right: 15px;">Off</label>
		<input type="radio" name="nlws_ehfi_meta[footer_mode]" id="nlws_ehfi_footer_mode_global" value="global" <?php nlws_ehfi_checked('global', $meta['footer_mode']); ?> class="nlws_ehfi_footermode" /> <label for="nlws_ehfi_footer_mode_global" style="padding-right: 15px;">Use Global Header</label>
		<input type="radio" name="nlws_ehfi_meta[footer_mode]" id="nlws_ehfi_footer_mode_perpage" value="perpage" <?php nlws_ehfi_checked('perpage', $meta['footer_mode']); ?> class="nlws_ehfi_footermode" /> <label for="nlws_ehfi_footer_mode_perpage">Use Per Page Header</label>
	</p>
	<pre class="nlws_ehfi_globalfooter" <?php if(!($meta['footer_mode']) || ($meta['footer_mode'] == 'off') || ($meta['footer_mode'] == 'perpage')) echo ' style="display: none"';?>><?php echo htmlspecialchars($options['global_footer']); ?></pre>
	<p class="nlws_ehfi_customfooter"  <?php if(!($meta['footer_mode']) || ($meta['footer_mode'] == 'off') || ($meta['footer_mode'] == 'global')) echo ' style="display: none"';?>>
		<textarea name="nlws_ehfi_meta[footer_text]" id="nlws_ehfi_meta[footer_text]" rows="8" style="width: 100%"><?php echo $meta['footer_text']; ?></textarea>
	</p>
	<script type="text/javascript">
		jQuery(function($){
			$('.nlws_ehfi_headermode:radio').click(function(){
				mode = $(this).val();
				
				switch (mode) {
					case 'off':
						$('.nlws_ehfi_globalheader').slideUp('fast', function(){
							$('.nlws_ehfi_customheader').slideUp();
						});
						break;
					case 'global':						
						$('.nlws_ehfi_customheader').slideUp('fast', function(){
							$('.nlws_ehfi_globalheader').slideDown('fast');
						});
						break;
					case 'perpage':
						$('.nlws_ehfi_globalheader').slideUp('fast', function(){
							$('.nlws_ehfi_customheader').slideDown();
						});
						break;
				}
			});
			
			$('.nlws_ehfi_footermode:radio').click(function(){
				mode = $(this).val();
				
				switch (mode) {
					case 'off':
						$('.nlws_ehfi_globalfooter').slideUp('fast', function(){
							$('.nlws_ehfi_customfooter').slideUp();
						});
						break;
					case 'global':
						$('.nlws_ehfi_customfooter').slideUp('fast', function(){
							$('.nlws_ehfi_globalfooter').slideDown('fast');
						});
						break;
					case 'perpage':
						$('.nlws_ehfi_globalfooter').slideUp('fast', function(){
							$('.nlws_ehfi_customfooter').slideDown();
						});
						break;
				}
			});
		});
	</script>
	
<?php }

function nlws_ehfi_head(){
	global $post;
	
	$meta = get_post_meta($post->ID,'_nlws_efhi',TRUE);
	$options = get_option( 'nlws_ehfi_settings' );
	
	if ($options['enable_post_type_' . $post->post_type] == 1) {
		switch ($meta['header_mode']) {
			case 'global' :
				echo $options['global_header'];
				break;
			case 'perpage' :
				echo $meta['header_text'];
				break;
		}
	}
}

function nlws_ehfi_footer(){
	global $post;
	
	$meta = get_post_meta($post->ID,'_nlws_efhi',TRUE);
	$options = get_option( 'nlws_ehfi_settings' );
	
	if ($options['enable_post_type_' . $post->post_type] == 1) {
		switch ($meta['footer_mode']) {
			case 'global' :
				echo $options['global_footer'];
				break;
			case 'perpage' :
				echo $meta['footer_text'];
				break;
		}
	}
}